import os
import logging
config_file = "logging.conf"

if not os.path.exists(config_file):
    raise FileNotFoundError(f"Logging config file not found: {config_file}")
logging.config.fileConfig(config_file, disable_existing_loggers=False)


import logging
import logging.config
import os


def ping():
    logging.getLogger(__name__).info("Ping received")
    return "pong"

if __name__ == "__main__":
    logger = logging.getLogger(__name__)
    logger.debug("Starting test module")
    import beanycro.test.test2.tmp
    print(ping())
    logger.info("Test module finished")